# transientNamer



[![](https://zenodo.org/badge/53676687.svg)](https://zenodo.org/badge/latestdoi/53676687) 


<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/transientNamer)](https://pypi.org/project/transientNamer/)  
[![](https://img.shields.io/pypi/v/transientNamer)](https://pypi.org/project/transientNamer/)  
[![](https://img.shields.io/github/license/thespacedoctor/transientNamer)](https://github.com/thespacedoctor/transientNamer)  
[![](https://img.shields.io/pypi/dm/transientNamer)](https://pypi.org/project/transientNamer/)  

<!-- STATUS BADGES -->  

[![](http://157.245.42.153:8080/buildStatus/icon?job=transientNamer%2Fmaster&subject=build%20master)](http://157.245.42.153:8080/blue/organizations/jenkins/transientNamer/activity?branch=master)  
[![](http://157.245.42.153:8080/buildStatus/icon?job=transientNamer%2Fdevelop&subject=build%20dev)](http://157.245.42.153:8080/blue/organizations/jenkins/transientNamer/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/transientNamer@master/coverage.svg)](https://raw.githack.com/thespacedoctor/transientNamer/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/transientNamer/badge/?version=master)](https://transientNamer.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/transientNamer/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/transientNamer/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*Python API for reading and caching TNS reports*.

Documentation for transientNamer is hosted by [Read the Docs](https://transientNamer.readthedocs.io/en/master/) ([development version](https://transientNamer.readthedocs.io/en/develop/) and [master version](https://transientNamer.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/transientNamer). Please report any issues you find [here](https://github.com/thespacedoctor/transientNamer/issues).

## Features

* 

## How to cite transientNamer

If you use `transientNamer` in your work, please cite using the following BibTeX entry: 

```bibtex
@software{Young_transientNamer,
    author = {Young, David R.},
    doi = {10.5281/zenodo.7970680},
    license = {GPL-3.0-only},
    title = {{transientNamer}},
    url = {https://github.com/thespacedoctor/transientNamer}
}
```
 


